==> legacylisten-0.1.0.crate: legacylisten-0.1.0/src/l10n/german.rs <==
pub static GERMAN_L10N_STR: &str = "
-name = legacylisten
-likelihood = Spielwahrscheinlichkeit
total-playing-likelihood = Insgesamte {-likelihood}: { $val }
help-notice = Tippe `?` um eine Hilfe anzuzeigen
unknown-command-char = Unbekannter Befehl: { $char }
unknown-command-byte = Unbekannter Befehl: { $byte }
in-signal-handler = Im Signalhandler von Signal { $sig }
signal-handler-unreachable = Alle möglichen Signale schon abgedeckt!
mpris-handler-error = Fehler mit MPRIS: { $err }
memory-tight = RAM ist sehr knapp, stoppe …
new-song-found = Neues Lied gefunden: { $filename }
no-songs = Keine spielbaren Lieder
print-playing-song = Zeige Informationen über das aktuelle Lied an
title = Titel
album = Album
artist = Künstler
album-artist = Künstler des Albums
year = Jahr
genre = Genre
date-recorded = Aufzeichnungsjahr
date-released = Veröffentlichungsjahr
disc = CDs #
discs-total = CDs insgesamt #
track = Tracks #
tracks-total = Tracks insgesamt #
duration = Dauer
lyrics = Liedtext
sync-lyrics = Synchronisierter Liedtext
comment = Kommentar
num-pictures = Bilder #
ext-links = ————Extended Links————
ext-texts = ————Extended Texts————
metadata-unsupported = Metadaten sind nicht unterstützt in diesem Lied
print-info-unreachable = Das sollte nicht erreicht werden
max-likelihood-reached = Maximale {-likelihood} ist schon erreicht
likelihood-increased = {-likelihood} erhöht auf { $likelihood }
song-already-never = Lied wird bereits nie wieder gespielt
likelihood-decreased = {-likelihood} vermindert auf { $likelihood }
song-never = Lied wird nie wieder gespielt werden
stopping-program = Beende {-name}
already-paused = Bereits angehalten
pausing = Halte an
resuming = Setze das Abspielen wieder fort
already-running = Lied wird bereits abgespielt
skipping-song = Überspringe Lied
making-louder = Erhöhe Lautstärke auf { $loud }%
making-quieter = Verringere Lautstärke auf { $loud }%
loud-zero = Versucht Lautstärke unter Null zu verringern; nutze 0%
duration-known = { $pos }s von { $len }s
duration-unknown = { $pos }s von {\"{unbekannt}\"}
already-quitting = Nach diesem Lied wird {-name} bereits beendet werden
quitting-after = Nach diesem Lied wird {-name} beendet
already-pausing = Nach diesem Lied wird bereits angehalten werden
pausing-after = Nach diesem Lied wird angehalten
opening-picture = Öffne Bild
nothing-playing-yet = Es wird noch kein Lied gespielt
cant-open-picture = Kann Bild nicht öffnen
not-repeating-already = Wiederholt bereits nicht
stopping-repeating = Stoppe das Lied zu wiederholen
already-repeating-once = Wiederhole bereits einmal
repeating-once = Werde das Lied einmal wiederholen
already-repeating-forever = Wiederhole bereits für immer
repeating-forever = Werde das Lied für immer wiederholen
already-playing-first = Spiele bereits das erste Lied in der Playlist
increase-likelihood = {-likelihood} des aktuellen Lieds erhöhen
decrease-likelihood = {-likelihood} des aktuellen Lieds verringern
quit = Programm beenden
pause = Abspielen anhalten
resume = Abspielen fortsetzen
skip = Lied überspringen
increase-volume = Lautstärke des aktuellen Lieds erhöhen
decrease-volume = Lautstärke des aktuellen Lieds verringern
show-duration = Dauer anzeigen
switch-play-pause = Zwischen Abspielen und Anhalten wechseln
quit-after-song = Das Programm nach diesem Lied beenden
pause-after-song = Das Abspielen nach diesem Lied anhalten
show-info = Informationen über das diese Lied anzeigen
open-cover = Cover in einem externen Programm öffnen
disable-repeat = Wiederholen des aktuellen Lieds beenden
repeat-once = Diese Lied einmal wiederholen
repeat-forever = Diese Lied ewig wiederholen
skip-to-previous = Zum vorherigen Lied springen
help-header = Drücke die Taste, die zu dem Befehl gehört, der ausgeführt werden soll:
command-reading-problem = Problem mit dm Lesen von Befehlen; stoppe …
reading-song-problem = Problem das Lied { $path } zu lesen : { $err }
choosing-new-song = Wähle neues Lied
playing-song = Gespieltes Lied: { $song }
playing-song-unknown = Spiele Lied mit einem komischen Namen
song-likelihood = Die {-likelihood} dieses Liedes ist { $likelihood }.
signal-paused = Wegen einem Signal angehalten
requested-pause = Halte an gemäß eines früheren Befehls
saving-state-err = Problem die Konfiguration zu speichern
state-saved = Konfiguration erfolgreich gespeichert
unknown-title = Unbekannter Titel
unknown-artist = Unbekannter Künstler
previous = Werde das vorherige Lied spielen
controller-out = Controllerkanal ist out of scope; das ist ein Bug, bitte melde ihn
";
pub static GERMAN_L10N_LANG_ID: &str = "de-DE";

==> legacylisten-0.1.1.crate: legacylisten-0.1.1/src/l10n/german.rs <==
pub static GERMAN_L10N_STR: &str = "
-name = legacylisten
-likelihood = Spielwahrscheinlichkeit
total-playing-likelihood = Insgesamte {-likelihood}: { $val }
help-notice = Tippe `?` um eine Hilfe anzuzeigen
unknown-command-char = Unbekannter Befehl: { $char }
unknown-command-byte = Unbekannter Befehl: { $byte }
in-signal-handler = Im Signalhandler von Signal { $sig }
signal-handler-unreachable = Alle möglichen Signale schon abgedeckt!
mpris-handler-error = Fehler mit MPRIS: { $err }
memory-tight = RAM ist sehr knapp, stoppe …
new-song-found = Neues Lied gefunden: { $filename }
no-songs = Keine spielbaren Lieder
print-playing-song = Zeige Informationen über das aktuelle Lied an
title = Titel
album = Album
artist = Künstler
album-artist = Künstler des Albums
year = Jahr
genre = Genre
date-recorded = Aufzeichnungsjahr
date-released = Veröffentlichungsjahr
disc = CDs #
discs-total = CDs insgesamt #
track = Tracks #
tracks-total = Tracks insgesamt #
duration = Dauer
lyrics = Liedtext
sync-lyrics = Synchronisierter Liedtext
comment = Kommentar
num-pictures = Bilder #
ext-links = ————Extended Links————
ext-texts = ————Extended Texts————
metadata-unsupported = Metadaten sind nicht unterstützt in diesem Lied
print-info-unreachable = Das sollte nicht erreicht werden
max-likelihood-reached = Maximale {-likelihood} ist schon erreicht
likelihood-increased = {-likelihood} erhöht auf { $likelihood }
song-already-never = Lied wird bereits nie wieder gespielt
likelihood-decreased = {-likelihood} vermindert auf { $likelihood }
song-never = Lied wird nie wieder gespielt werden
stopping-program = Beende {-name}
already-paused = Bereits angehalten
pausing = Halte an
resuming = Setze das Abspielen wieder fort
already-running = Lied wird bereits abgespielt
skipping-song = Überspringe Lied
making-louder = Erhöhe Lautstärke auf { $loud }%
making-quieter = Verringere Lautstärke auf { $loud }%
loud-zero = Versucht Lautstärke unter Null zu verringern; nutze 0%
duration-known = { $pos }s von { $len }s
duration-unknown = { $pos }s von {\"{unbekannt}\"}
already-quitting = Nach diesem Lied wird {-name} bereits beendet werden
quitting-after = Nach diesem Lied wird {-name} beendet
already-pausing = Nach diesem Lied wird bereits angehalten werden
pausing-after = Nach diesem Lied wird angehalten
opening-picture = Öffne Bild
nothing-playing-yet = Es wird noch kein Lied gespielt
cant-open-picture = Kann Bild nicht öffnen
not-repeating-already = Wiederholt bereits nicht
stopping-repeating = Stoppe das Lied zu wiederholen
already-repeating-once = Wiederhole bereits einmal
repeating-once = Werde das Lied einmal wiederholen
already-repeating-forever = Wiederhole bereits für immer
repeating-forever = Werde das Lied für immer wiederholen
already-playing-first = Spiele bereits das erste Lied in der Playlist
increase-likelihood = {-likelihood} des aktuellen Lieds erhöhen
decrease-likelihood = {-likelihood} des aktuellen Lieds verringern
quit = Programm beenden
pause = Abspielen anhalten
resume = Abspielen fortsetzen
skip = Lied überspringen
increase-volume = Lautstärke des aktuellen Lieds erhöhen
decrease-volume = Lautstärke des aktuellen Lieds verringern
show-duration = Dauer anzeigen
switch-play-pause = Zwischen Abspielen und Anhalten wechseln
quit-after-song = Das Programm nach diesem Lied beenden
pause-after-song = Das Abspielen nach diesem Lied anhalten
show-info = Informationen über das diese Lied anzeigen
open-cover = Cover in einem externen Programm öffnen
disable-repeat = Wiederholen des aktuellen Lieds beenden
repeat-once = Diese Lied einmal wiederholen
repeat-forever = Diese Lied ewig wiederholen
skip-to-previous = Zum vorherigen Lied springen
help-header = Drücke die Taste, die zu dem Befehl gehört, der ausgeführt werden soll:
command-reading-problem = Problem mit dm Lesen von Befehlen; stoppe …
reading-song-problem = Problem das Lied { $path } zu lesen : { $err }
choosing-new-song = Wähle neues Lied
playing-song = Gespieltes Lied: { $song }
playing-song-unknown = Spiele Lied mit einem komischen Namen
song-likelihood = Die {-likelihood} dieses Liedes ist { $likelihood }.
signal-paused = Wegen einem Signal angehalten
requested-pause = Halte an gemäß eines früheren Befehls
saving-state-err = Problem die Konfiguration zu speichern
state-saved = Konfiguration erfolgreich gespeichert
unknown-title = Unbekannter Titel
unknown-artist = Unbekannter Künstler
previous = Werde das vorherige Lied spielen
controller-out = Controllerkanal ist out of scope; das ist ein Bug, bitte melde ihn
too-many-tries = Zu viele erfolglose Versuche ein Lied zu lesen; wahrscheinlich sind alle Lieder unspielbar; stoppe …
";
pub static GERMAN_L10N_LANG_ID: &str = "de-DE";
